/*
 * timer.h
 * Header file for timer utility functions.
 *
 * Copyright (C) 2021 IOPSYS Software Solutions AB. All rights reserved.
 *
 * Author: anjan.chanda@iopsys.eu
 *
 * See LICENSE file for license related information.
 *
 */

#ifndef ATIMER_H
#define ATIMER_H

#include "timer_impl.h"

#ifndef ATIMER_T
#error "atimer_t not defined!"
#endif

#include <stdbool.h>
#include <time.h>

void timer_init(atimer_t *t, void (*function)(atimer_t *));
int timer_set(atimer_t *t, uint32_t tmo_ms);
int timer_del(atimer_t *t);
int timer_pending(atimer_t *t);
int timer_remaining_ms(atimer_t *t);

void timestamp_reset(struct timespec *ts);
void timestamp_update(struct timespec *ts);
int timestamp_invalid(struct timespec *ts);

bool timestamp_less_than(const struct timespec *lhs, const struct timespec *rhs);
bool timestamp_greater_than(const struct timespec *lhs, const struct timespec *rhs);
bool timestamp_greater_or_equal(const struct timespec *lhs, const struct timespec *rhs);
bool timestamp_less_or_equal(const struct timespec *lhs, const struct timespec *rhs);

uint32_t timestamp_elapsed_sec(const struct timespec *ts);
int timestamp_expired(struct timespec *a, unsigned int tmo_ms);
char *time_to_timestamp(const time_t *t, char *tsp);
time_t timestamp_to_time(const char *tsp);
struct timespec time_to_timespec(time_t t);
struct timespec timestamp_to_timespec(const char *tsp, bool adj_rtime);


#endif /* ATIMER_H */
